LSDB Rubin
========================================================================================

Suite of utilities for interacting with Rubin LSST data within LSDB.

Getting Started
---------------------------

The ``lsdb-rubin`` package is released via `PyPi <https://pypi.org/project/lsdb-rubin/>`__
and can be installed with 

.. code-block:: bash

   pip install lsdb-rubin

If you don't already have ``lsdb`` installed in your environment, it will be installed
as a dependency of ``lsdb-rubin``.

.. toctree::
   :hidden:

   Home page <self>
   API Reference <reference/index>
   Notebooks <notebooks>
